Disclaimer
I am not a specialist in this field. This project is highly speculative and requires magical thinking/suspension of belief in order to function. It is not intended to be a serious tool for psychology, only a curiousity. I've found the mathematical coherence of the enneagram to be somewhat fascinating, and therefore conceptualized this absurd piece of software.
Introduction to the enneagram
Although you can often find it in fiction, i don't think i've ever met a real person in my life who is persistantly found at one of the arms of the nonagon at all times. We all move around in it from day to day or hour to hour. I would imagine that you'd agree to some extent. You mentioned several times how it can be repurposed as a lens to view momentary motivations or strategies. The whole thing seems like an emergant combinatoric pattern that takes form when one takes personality and describe it as the composition of [internal suffering/frame] + [external means/action] + [internal means/fault] + [external suffering/need], and define the system as consisting of two free variables where each variable (dependent or independent) has three possible states.
Schopenhauer would say that all experience is derivative of suffering (right or not).
To be clear: all of this describes the mind, so it's all internal, but by "internal" i mean more internal than the internal.
We can take the axiom of suffering = thesis, means = anti-thesis, personality = synthesis, in Hegel's model of: thesis + anti-thesis = synthesis, but modified to separate the internal and the external, and it starts to look familiar.
The room of possibilities contains two free variables. So identifying two of the four triads is enough to narrow down a specific personality type within this system (accurate or not). So supposedly, knowing only two of these should be enough to predict the two other. I'm not sure if that's the case.
If not, we'd have 3^4 = 27 personality types instead of 9.
Humonculus of the self/internalization of self/frame of judgement/meta-objective/"Who am i?": 891 - Gut/"i am my urges, my concience hurts me" 567 - Head/"i am my thoughts, my fear hurts me" 234 - Heart/"i am my emotions, my feelings hurt me"
External strategy towards suffering: 378 - Assertive/"i can change it" 612 - Compliant/"i can tolerate it" 945 - Withdrawn/"i can avoid it"
Internal strategy for one's (meta-)suffering/"who to blame?": 792 - Positive/"Everything is fine" 135 - Competent/"I take responsibility" 468 - Reactive/"it's their fault"
Need/object of desire/"what hole do you have in your soul?" 369 - Attachment/"i need freedom" 147 - Frustration/"i need control" 258 - Rejection/"i need love"
There's a few things that are still a bit unclear to me. Are there combinations of the above that are not covered by the enneagram's 9 personality types? (could there in fact be 27 in total?) What's the deal with the interconnections/lines? Do they describe structural or dynamic pathways or relations between the types?
On causality
Enneagram triad pairs: IN = External dissonance - Thesis: need - Anti-thesis: fault EN = External conflict - Thesis: need - Anti-thesis: action EI = Behaviour - Introverted: fault - Extroverted: action HN = Suffering - Introverted: frame - Extroverted: need HI = Internal conflict - Thesis: frame - Anti-thesis: fault HE = Internal dissonance - Thesis: frame - Anti-thesis: action
Cause and effect: HE->IN = Internal dissonance predicts external dissonance HI->EN = Internal conflict predicts external conflict HN->EI = Suffering predicts behaviour EI->HN = Behaviour indicates suffering EN->HI = External conflict indicates internal conflict IN->HE = External dissonance indicates internal dissonance
-
Recovery / Gradient H = I am my urges, my concience hurts me E = I can tolerate it I = I take responsibility N = I need control
-
Association / Superego H = I am my emotions, my feelings hurt me E = I can tolerate it I = Everything is fine N = I need love
-
Repression / Ego H = I am my emotions, my feelings hurt me E = I can change it I = I take responsibility N = I need freedom
-
Rejection / Id H = I am my emotions, my feelings hurt me E = I can avoid it I = It's their fault N = I need control
-
Catatonia H = I am my thoughts, my fear hurts me E = I can avoid it I = I take responsibility N = I need love
-
Paranoia / H = I am my thoughts, my fear hurts me E = I can tolerate it I = It's their fault N = I need freedom
-
Disorganization / H = I am my thoughts, my fear hurts me E = I can change it I = Everything is fine N = I need control
-
Action / H = I am my urges, my conscience hurts me E = I can change it I = It's their fault N = I need love
-
Rest / H = I am my urges, my conscience hurts me E = I can avoid it I = Everything is fine N = I need freedom
Enneagram, the computer program
I'm writing a computer program that's essentially like a magic 8 ball but with basis on the enneagram/schizogram.
The combinatorics of it all makes it possible to determine one's placement on the enneagram if a pair of triads are given. The two other triads are then dependent. Looking at all the combinations, i've come to find that this combinatoric dependence between the triads (two degrees of freedom) makes emergent sense. It's interesting how the supposed answers for each question (consisting of two triads) results in a mostly reasonable assumption about someone's inner and outer spiritual conflict. A pair of triads can be referred to as either: a cause, or an effect. The other cause, consisting of another pair, can be determined from any effect and vice versa. Both pairs are dependent variables. If you have defined one pair, the other is pre-determined. Each cause/effect consists of a pair of triads of the enneagram.
So by having a computer program ask three questions, you can, (surprisingly enough!) get a reasonably useful answer from it:
- Which kind of inferrence will we make?
- Internal dissonance (humonculus + external strategy)
- internal conflict (humonculus + internal strategy)
- suffering (humonculus + need)
- behaviour (external and internal strategy)
- external conflict (external strategy + need)
- external dissonance (internal strategy + need)
- Select first triad
- Select second triad Voilla: an answer will be produced! That's the idea at least.
The conflicts are congruant while the dissonances are incongruant. Often, two triads reside in the conscious and the other two reside in the subconscious.
Interconnections
I've figured out by now that the lines between each state make perfect sense. They'd point to the other state you would get if you were to change one of the two known triads. I could allow the user to make a choice after their placement has been determined, to change one triad and thereby move between the enneagram's edges.
Installation
Arch-Linux
This program is available as a PKGBUILD on the AUR.
yay -S enneagram
Others
You need the rust toolchain installed on your computer. Run the command cargo install enneagram.